@@ -15,9 +15,7 @@ $ export MY_LOG_STYLE=never
 ```
 */
 
-#[macro_use]
-extern crate log;
-extern crate env_logger;
+use log::{debug, error, info, trace, warn};
 
 use env_logger::Env;
 
